@@ -27,6 +27,7 @@
 #' @examples
 #' # read in rvt file
 #' system.file('extdata','GlenAllan.rvt',package="RavenR") %>%
+#'
 #' rvn_rvt_read(.) -> rvt
 #' plot(rvt$rvt_xts$TEMP_DAILY_MIN)
 #'
@@ -210,6 +211,12 @@ rvn_rvt_read<-function(filename, tzone="UTC") {
             }
           }
 
+          # check time interval, convert to numeric if needed
+          if (is.na(as.numeric(meta_df[meta_df$param=="time_interval","value"]))) {
+            meta_df[meta_df$param=="time_interval","value"] <-
+              hhmmss2dec(meta_df[meta_df$param=="time_interval","value"])/24
+          }
+
           dd.xts <- xts(dd, order.by=seq.POSIXt(from=as.POSIXct(sprintf("%s %s",
                                                                         meta_df[meta_df$param=="start_date","value"],
                                                                         meta_df[meta_df$param=="start_time","value"]),
@@ -403,6 +410,12 @@ rvn_rvt_read<-function(filename, tzone="UTC") {
             }
           }
 
+          # check time interval, convert to numeric if needed
+          if (is.na(as.numeric(meta_df[meta_df$param=="time_interval","value"]))) {
+            meta_df[meta_df$param=="time_interval","value"] <-
+              hhmmss2dec(meta_df[meta_df$param=="time_interval","value"])/24
+          }
+
           dd.xts <- xts(dd, order.by=seq.POSIXt(from=as.POSIXct(sprintf("%s %s",
                                                                         meta_df[meta_df$param=="start_date","value"],
                                                                         meta_df[meta_df$param=="start_time","value"]),
@@ -416,6 +429,9 @@ rvn_rvt_read<-function(filename, tzone="UTC") {
     }
   }
 
+  # update time interval to numeric
+
+
   return(list(
     "rvt_xts"=dd.xts,
     "rvt_metadata"=meta_df
